@@ -20,16 +20,17 @@
 var args = process.argv.slice(2)
   , libPath = __dirname + '/../lib'
   , fs = require('fs')
-  , jake = require(libPath + '/jake.js')
-  , api = require(libPath + '/api.js')
-  , utils = require(libPath + '/utils.js')
-  , Program = require(libPath + '/program.js').Program
+  , jake = require(libPath + '/jake')
+  , api = require(libPath + '/api')
+  , utils = require(libPath + '/utils')
+  , Program = require(libPath + '/program').Program
   , program = new Program()
-  , Loader = require(libPath + '/loader.js').Loader
+  , Loader = require(libPath + '/loader').Loader
   , loader = new Loader()
   , pkg = JSON.parse(fs.readFileSync(__dirname + '/../package.json').toString())
   , opts
-  , envVars;
+  , envVars
+  , taskNames;
 
 jake.version = pkg.version;
 
@@ -50,16 +51,19 @@ if (!program.preemptiveOption()) {
     global[p] = api[p];
   }
 
-  jake.exec = utils.exec;
-
-  // Get convenient refs to FileList, PackageTask
-  jake.FileList = require(libPath + '/file_list').FileList
-  jake.PackageTask = require(libPath + '/package_task').PackageTask
+  // Convenience aliases
+  jake.opts = opts;
+  for (var p in utils) {
+    jake[p] = utils[p];
+  }
+  jake.FileList = require(libPath + '/file_list').FileList;
+  jake.PackageTask = require(libPath + '/package_task').PackageTask;
+  jake.NpmPublishTask = require(libPath + '/npm_publish_task').NpmPublishTask;
 
   // Enhance env with any env vars passed in
   for (var p in envVars) { process.env[p] = envVars[p]; }
 
-  loader.load(opts.jakefile);
+  loader.load(opts);
 
   // Set working dir
   var dirname = opts.directory;
@@ -67,13 +71,15 @@ if (!program.preemptiveOption()) {
     process.chdir(dirname);
   }
 
-  jake.parseAllTasks();
+  taskNames = program.taskNames;
+  taskNames = taskNames.length ? taskNames : ['default'];
+  task('__root__', taskNames, function () {});
 
   if (opts.tasks) {
     jake.showAllTaskDescriptions(opts.tasks);
   }
   else {
-    jake.runTask(program.taskName || 'default', program.taskArgs, true);
+    jake.Task['__root__'].invoke();
   }
 }
 
